pub struct ByteCacheKey {
pub archive_hash: u64,
pub inner_path: String,
}Expand description
Cache key identifying one extracted entry: its source archive hash plus the inner path within that archive.
Fields
archive_hash: u64inner_path: StringTrait Implementations
Sourceimpl Clone for ByteCacheKey
impl Clone for ByteCacheKey
Sourcefn clone(&self) -> ByteCacheKey
fn clone(&self) -> ByteCacheKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ByteCacheKey
impl Debug for ByteCacheKey
Sourceimpl Hash for ByteCacheKey
impl Hash for ByteCacheKey
Sourceimpl PartialEq for ByteCacheKey
impl PartialEq for ByteCacheKey
Sourcefn eq(&self, other: &ByteCacheKey) -> bool
fn eq(&self, other: &ByteCacheKey) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ByteCacheKey
impl StructuralPartialEq for ByteCacheKey