pub struct LoadedApiKey {
pub key: String,
pub source: ApiKeySource,
}Expand description
A resolved Nexus API key together with the source it came from.
Fields
key: Stringsource: ApiKeySourceTrait Implementations
Sourceimpl Clone for LoadedApiKey
impl Clone for LoadedApiKey
Sourcefn clone(&self) -> LoadedApiKey
fn clone(&self) -> LoadedApiKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoadedApiKey
impl Debug for LoadedApiKey
Sourceimpl PartialEq for LoadedApiKey
impl PartialEq for LoadedApiKey
Sourcefn eq(&self, other: &LoadedApiKey) -> bool
fn eq(&self, other: &LoadedApiKey) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for LoadedApiKey
impl StructuralPartialEq for LoadedApiKey