pub struct ArchiveBatchExtractor;Expand description
Stateless entry point for selective, single-pass archive extraction.
Implementations
Sourceimpl ArchiveBatchExtractor
impl ArchiveBatchExtractor
Sourcepub fn extract_selected(
path: &Path,
requests: &[ArchiveRequest],
) -> Result<ArchiveBatchOutput>
pub fn extract_selected( path: &Path, requests: &[ArchiveRequest], ) -> Result<ArchiveBatchOutput>
Extract the requested entries from the archive at path.
Errors
Returns an error for unsupported formats, unsafe entry paths, size mismatches, or any requested entry that is missing.
Sourcepub fn extract_selected_from(
input: ArchiveInput<'_>,
requests: &[ArchiveRequest],
) -> Result<ArchiveBatchOutput>
pub fn extract_selected_from( input: ArchiveInput<'_>, requests: &[ArchiveRequest], ) -> Result<ArchiveBatchOutput>
Extract the requested entries from input (a path or in-memory bytes).
Errors
Returns an error for unsupported formats, unsafe entry paths, size mismatches, or any requested entry that is missing.